==> docusign-esign-java-4.6.0-sources.jar: com/docusign/esign/model/AccountPasswordLockoutDurationType.java <==
package com.docusign.esign.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.v3.oas.annotations.media.Schema;
import java.util.Objects;

/** AccountPasswordLockoutDurationType. */
public class AccountPasswordLockoutDurationType {
  @JsonProperty("options")
  private java.util.List<String> options = null;

  /**
   * options.
   *
   * @return AccountPasswordLockoutDurationType
   */
  public AccountPasswordLockoutDurationType options(java.util.List<String> options) {
    this.options = options;
    return this;
  }

  /**
   * addOptionsItem.
   *
   * @return AccountPasswordLockoutDurationType
   */
  public AccountPasswordLockoutDurationType addOptionsItem(String optionsItem) {
    if (this.options == null) {
      this.options = new java.util.ArrayList<>();
    }
    this.options.add(optionsItem);
    return this;
  }

  /**
   * .
   *
   * @return options
   */
  @Schema(description = "")
  public java.util.List<String> getOptions() {
    return options;
  }

  /** setOptions. */
  public void setOptions(java.util.List<String> options) {
    this.options = options;
  }

  /**
   * Compares objects.
   *
   * @return true or false depending on comparison result.
   */
  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    AccountPasswordLockoutDurationType accountPasswordLockoutDurationType =
        (AccountPasswordLockoutDurationType) o;
    return Objects.equals(this.options, accountPasswordLockoutDurationType.options);
  }

  /** Returns the HashCode. */
  @Override
  public int hashCode() {
    return Objects.hash(options);
  }

  /** Converts the given object to string. */
  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class AccountPasswordLockoutDurationType {\n");

    sb.append("    options: ").append(toIndentedString(options)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}

==> docusign-esign-java-6.4.0-sources.jar: com/docusign/esign/model/AccountPasswordLockoutDurationType.java <==
package com.docusign.esign.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.v3.oas.annotations.media.Schema;
import java.io.Serializable;
import java.util.Objects;

/** AccountPasswordLockoutDurationType. */
public class AccountPasswordLockoutDurationType implements Serializable {
  private static final long serialVersionUID = 1L;

  @JsonProperty("options")
  private java.util.List<String> options = null;

  /**
   * options.
   *
   * @return AccountPasswordLockoutDurationType
   */
  public AccountPasswordLockoutDurationType options(java.util.List<String> options) {
    this.options = options;
    return this;
  }

  /**
   * addOptionsItem.
   *
   * @return AccountPasswordLockoutDurationType
   */
  public AccountPasswordLockoutDurationType addOptionsItem(String optionsItem) {
    if (this.options == null) {
      this.options = new java.util.ArrayList<>();
    }
    this.options.add(optionsItem);
    return this;
  }

  /**
   * .
   *
   * @return options
   */
  @Schema(description = "")
  public java.util.List<String> getOptions() {
    return options;
  }

  /** setOptions. */
  public void setOptions(java.util.List<String> options) {
    this.options = options;
  }

  /**
   * Compares objects.
   *
   * @return true or false depending on comparison result.
   */
  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    AccountPasswordLockoutDurationType accountPasswordLockoutDurationType =
        (AccountPasswordLockoutDurationType) o;
    return Objects.equals(this.options, accountPasswordLockoutDurationType.options);
  }

  /** Returns the HashCode. */
  @Override
  public int hashCode() {
    return Objects.hash(options);
  }

  /** Converts the given object to string. */
  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class AccountPasswordLockoutDurationType {\n");

    sb.append("    options: ").append(toIndentedString(options)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
